@@ -583,9 +583,9 @@ $(document).ready(function() {
 							});
 	
 	//iPad Viewport
-	if( navigator.userAgent.match(/iPad/i) != null ){  
+	if( navigator.userAgent.match(/iPad/i) == null ){  
 		viewport = document.querySelector("meta[name=viewport]");  
-		viewport.setAttribute('content', "width=device-width, maximum-scale=0.9, user-scalable=no");  
+		viewport.setAttribute('content', "width=777, initial-scale=0.3");  
 	}
 });
 
